==> krusader_1.60.1.orig.tar.gz: krusader-1.60.1/krusader/GUI/krusaderstatus.cpp <==
/***************************************************************************
                 krusaderstatus.cpp
                             -------------------
    copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
    e-mail               : krusader@users.sourceforge.net
    web site             : http://krusader.sourceforge.net
 ---------------------------------------------------------------------------
  Description 
 ***************************************************************************

  A 

     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD

                                                     S o u r c e    F i l e

 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// Krusader includes
#include <qfontmetrics.h>
#include "krusaderstatus.h"
#include "../resources.h"


KrusaderStatus::KrusaderStatus(QWidget *parent, const char *name ):
  KStatusBar(parent,name){
	insertItem(S_READY,S_READY_ID);
	setMaximumHeight(QFontMetrics(font()).height()+2);
}

KrusaderStatus::~KrusaderStatus(){
}

#include "krusaderstatus.moc"

==> krusader_15.08~2015.11.01.orig.tar.gz: krusader-15.08~2015.11.01/krusader/GUI/krusaderstatus.cpp <==
/***************************************************************************
                 krusaderstatus.cpp
                             -------------------
    copyright            : (C) 2000 by Shie Erlich & Rafi Yanai
    e-mail               : krusader@users.sourceforge.net
    web site             : http://krusader.sourceforge.net
 ---------------------------------------------------------------------------
  Description
 ***************************************************************************

  A

     db   dD d8888b. db    db .d8888.  .d8b.  d8888b. d88888b d8888b.
     88 ,8P' 88  `8D 88    88 88'  YP d8' `8b 88  `8D 88'     88  `8D
     88,8P   88oobY' 88    88 `8bo.   88ooo88 88   88 88ooooo 88oobY'
     88`8b   88`8b   88    88   `Y8b. 88~~~88 88   88 88~~~~~ 88`8b
     88 `88. 88 `88. 88b  d88 db   8D 88   88 88  .8D 88.     88 `88.
     YP   YD 88   YD ~Y8888P' `8888Y' YP   YP Y8888D' Y88888P 88   YD

                                                     S o u r c e    F i l e

 ***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "krusaderstatus.h"

#include <QtGui/QFontMetrics>

#include <KI18n/KLocalizedString>

KrusaderStatus::KrusaderStatus(QWidget *parent):
    QStatusBar(parent)
{
    showMessage(i18n("Ready."), 5000);
    setMaximumHeight(QFontMetrics(font()).height() + 2);
}

KrusaderStatus::~KrusaderStatus()
{
}
